==> qt-creator-2.6.0-src.zip: qt-creator-2.6.0-src/src/plugins/projectexplorer/copytaskhandler.cpp <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "copytaskhandler.h"

#include "task.h"

#include <coreplugin/coreconstants.h>

#include <QDir>
#include <QAction>
#include <QApplication>
#include <QClipboard>

using namespace ProjectExplorer::Internal;

void CopyTaskHandler::handle(const ProjectExplorer::Task &task)
{
    QString type;
    switch (task.type) {
    case Task::Error:
        //: Task is of type: error
        type = tr("error: ");
        break;
    case Task::Warning:
        //: Task is of type: warning
        type = tr("warning: ");
        break;
    default:
        break;
    }

    QApplication::clipboard()->setText(task.file.toUserOutput() + QLatin1Char(':') +
                                       QString::number(task.line) + QLatin1String(": ")
                                       + type + task.description);
}

QAction *CopyTaskHandler::createAction(QObject *parent) const
{
    QAction *copyAction = new QAction(tr("&Copy", "Name of the action triggering the copytaskhandler"), parent);
    copyAction->setToolTip(tr("Copy task to clipboard"));
    return copyAction;
}

==> qt-creator-2.7.1-src.zip: qt-creator-2.7.1-src/src/plugins/projectexplorer/copytaskhandler.cpp <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "copytaskhandler.h"

#include "task.h"
#include "taskwindow.h"

#include <coreplugin/coreconstants.h>
#include <coreplugin/actionmanager/actionmanager.h>

#include <QDir>
#include <QAction>
#include <QApplication>
#include <QClipboard>

using namespace ProjectExplorer::Internal;

void CopyTaskHandler::handle(const ProjectExplorer::Task &task)
{
    QString type;
    switch (task.type) {
    case Task::Error:
        //: Task is of type: error
        type = tr("error: ");
        break;
    case Task::Warning:
        //: Task is of type: warning
        type = tr("warning: ");
        break;
    default:
        break;
    }

    QApplication::clipboard()->setText(task.file.toUserOutput() + QLatin1Char(':') +
                                       QString::number(task.line) + QLatin1String(": ")
                                       + type + task.description);
}

Core::Id CopyTaskHandler::actionManagerId() const
{
    return Core::Id(Core::Constants::COPY);
}

QAction *CopyTaskHandler::createAction(QObject *parent) const
{
    QAction *copyAction = new QAction(parent);
    return copyAction;
}
